@@ -46,7 +46,7 @@ import sys
 
 debug = True if os.environ.get('DEBUG') == 'true' else False 
 
-class DateMathException(BaseException):
+class DateMathException(Exception):
     pass 
 
 def unitMap(c):
@@ -107,6 +107,13 @@ def parse(expression, now=None, tz='UTC', type=None, roundDown=True):
             return getattr(now, type)
         else:
             return now
+    elif re.match('\d{10,}', str(expression)):
+        if debug: print('found an epoch timestamp')
+        if len(str(expression)) == 13:
+            raise DateMathException('Unable to parse epoch timestamps in millis, please convert to the nearest second to continue - i.e. 1451610061 / 1000')
+        ts = arrow.get(int(expression))
+        ts = ts.replace(tzinfo=tz)
+        return ts
     elif expression.startswith('now'):
         ''' parse our standard "now+1d" kind of queries '''
         math = expression[3:]
@@ -195,11 +202,14 @@ def evaluate(expression, now, timeZone='UTC', roundDown=True):
 
             try:
                 m = re.match('(\d*[.]?\d+)[\w+-/]', expression[i+1:])
-                num = m.group(1)
-                val = val * 10 + float(num)
-                i = i + len(num)
+                if m:
+                    num = m.group(1)
+                    val = val * 10 + float(num)
+                    i = i + len(num)
+                else:
+                    raise DateMathException('''Unable to determine a proper time qualifier.  Do you have a proper numerical number followed by a valid time unit? i.e. '+1d', '-3d/d', etc.''')
             except Exception as e:
-                raise DateMathException("Invalid numerical datematch: What I got was - match: {0}, expression: {1}, error: {2}".format(expression[i+1:], expression, e)) 
+                raise DateMathException("Invalid datematch: What I got was - re.match: {0}, expression: {1}, error: {2}".format(expression[i+1:], expression, e)) 
     
             if char == '+':
                 val = float(val)
@@ -207,6 +217,8 @@ def evaluate(expression, now, timeZone='UTC', roundDown=True):
                 val = float(-val)
         elif re.match('[a-zA-Z]+', char):
             now = calculate(now, val, unitMap(char))
+        else:
+            raise DateMathException(''''{}' is not a valid timeunit for expression: '{}' '''.format(char, expression))
         
         i += 1
     if debug: print("Fin: {0}".format(now))
